==> jc-1.4.0.tar.gz: gnu/java/security/provider/Gnu.h <==
// public final class gnu.java.security.provider.Gnu

// class file dependencies
// @dep_class 11bc72f6ef0165db gnu_java_security_provider_Gnu
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 81b073051aa30acc java_security_Provider
// @dep_class 9092106fecd0cf9 java_util_Dictionary
// @dep_class 576421c2c18f78c4 java_util_Hashtable
// @dep_class 884c3edb343dfb63 java_util_Properties

// header file dependencies
// @dep_header java_security_Provider

#include "java/security/Provider.h"

#ifndef _JC_gnu_java_security_provider_Gnu_H_
#define _JC_gnu_java_security_provider_Gnu_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_Gnu$sub_refs	_jc_gnu_java_security_provider_Gnu$sub_refs;
typedef struct _jc_gnu_java_security_provider_Gnu$sub_nonrefs	_jc_gnu_java_security_provider_Gnu$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_Gnu$refs	_jc_gnu_java_security_provider_Gnu$refs;
typedef struct _jc_gnu_java_security_provider_Gnu$nonrefs	_jc_gnu_java_security_provider_Gnu$nonrefs;
typedef struct _jc_gnu_java_security_provider_Gnu$object	_jc_gnu_java_security_provider_Gnu$object;

typedef struct _jc_gnu_java_security_provider_Gnu$fields_struct	_jc_gnu_java_security_provider_Gnu$fields_struct;
typedef const struct _jc_gnu_java_security_provider_Gnu$vmethods	_jc_gnu_java_security_provider_Gnu$vmethods;
typedef const struct _jc_gnu_java_security_provider_Gnu$vtable	_jc_gnu_java_security_provider_Gnu$vtable;
typedef const struct _jc_gnu_java_security_provider_Gnu$vtype	_jc_gnu_java_security_provider_Gnu$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_Gnu$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24CollectionCertStoreImpl;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSAKeyFactory;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSAKeyPairGenerator;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSAParameterGenerator;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSAParameters;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSASignature;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24EncodedKeyFactory;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24MD2withRSA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24MD4withRSA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24MD5;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24MD5withRSA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24PKIXCertPathValidatorImpl;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24RSAKeyFactory;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24SHA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24SHA1PRNG;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24SHA1withRSA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24X509CertificateFactory;
};
extern _jc_gnu_java_security_provider_Gnu$fields_struct _jc_gnu_java_security_provider_Gnu$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_Gnu$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_Gnu$object *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_Gnu$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_provider_Gnu$vmethods {
};

// Vtable
struct _jc_gnu_java_security_provider_Gnu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Dictionary$vmethods	java_util_Dictionary;
	_jc_java_util_Hashtable$vmethods	java_util_Hashtable;
	_jc_java_util_Properties$vmethods	java_util_Properties;
	_jc_java_security_Provider$vmethods	java_security_Provider;
	_jc_gnu_java_security_provider_Gnu$vmethods	gnu_java_security_provider_Gnu;
};

// Vtype
struct _jc_gnu_java_security_provider_Gnu$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_Gnu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_Gnu$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_Gnu$refs {
    _jc_gnu_java_security_provider_Gnu$sub_refs	gnu_java_security_provider_Gnu;
    _jc_java_security_Provider$sub_refs	java_security_Provider;
    _jc_java_util_Properties$sub_refs	java_util_Properties;
    _jc_java_util_Hashtable$sub_refs	java_util_Hashtable;
    _jc_java_util_Dictionary$sub_refs	java_util_Dictionary;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_Gnu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_Gnu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Dictionary$sub_nonrefs	java_util_Dictionary;
    _jc_java_util_Hashtable$sub_nonrefs	java_util_Hashtable;
    _jc_java_util_Properties$sub_nonrefs	java_util_Properties;
    _jc_java_security_Provider$sub_nonrefs	java_security_Provider;
    _jc_gnu_java_security_provider_Gnu$sub_nonrefs	gnu_java_security_provider_Gnu;
};

// Object instance structure
struct _jc_gnu_java_security_provider_Gnu$object {
	_jc_gnu_java_security_provider_Gnu$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_Gnu$vtype	*vtype;
	_jc_gnu_java_security_provider_Gnu$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_Gnu$vtype _jc_gnu_java_security_provider_Gnu$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_Gnu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_Gnu$class_object;

#endif	/* _JC_gnu_java_security_provider_Gnu_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/Gnu.h <==
// public final class gnu.java.security.provider.Gnu

// class file dependencies
// @dep_class 11bc72f6ef0165db gnu_java_security_provider_Gnu
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 81b073051aa30acc java_security_Provider
// @dep_class 9092106fecd0cf9 java_util_Dictionary
// @dep_class 576421c2c18f78c4 java_util_Hashtable
// @dep_class 884c3edb343dfb63 java_util_Properties

// header file dependencies
// @dep_header java_security_Provider

#include "java/security/Provider.h"

#ifndef _JC_gnu_java_security_provider_Gnu_H_
#define _JC_gnu_java_security_provider_Gnu_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_Gnu$sub_refs	_jc_gnu_java_security_provider_Gnu$sub_refs;
typedef struct _jc_gnu_java_security_provider_Gnu$sub_nonrefs	_jc_gnu_java_security_provider_Gnu$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_Gnu$refs	_jc_gnu_java_security_provider_Gnu$refs;
typedef struct _jc_gnu_java_security_provider_Gnu$nonrefs	_jc_gnu_java_security_provider_Gnu$nonrefs;
typedef struct _jc_gnu_java_security_provider_Gnu$object	_jc_gnu_java_security_provider_Gnu$object;

typedef struct _jc_gnu_java_security_provider_Gnu$fields_struct	_jc_gnu_java_security_provider_Gnu$fields_struct;
typedef const struct _jc_gnu_java_security_provider_Gnu$vmethods	_jc_gnu_java_security_provider_Gnu$vmethods;
typedef const struct _jc_gnu_java_security_provider_Gnu$vtable	_jc_gnu_java_security_provider_Gnu$vtable;
typedef const struct _jc_gnu_java_security_provider_Gnu$vtype	_jc_gnu_java_security_provider_Gnu$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_Gnu$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24CollectionCertStoreImpl;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSAKeyFactory;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSAKeyPairGenerator;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSAParameterGenerator;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSAParameters;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24DSASignature;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24EncodedKeyFactory;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24MD2withRSA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24MD4withRSA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24MD5;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24MD5withRSA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24PKIXCertPathValidatorImpl;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24RSAKeyFactory;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24SHA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24SHA1PRNG;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24SHA1withRSA;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24provider__24X509CertificateFactory;
};
extern _jc_gnu_java_security_provider_Gnu$fields_struct _jc_gnu_java_security_provider_Gnu$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_Gnu$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_Gnu$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_Gnu$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_provider_Gnu$vmethods {
};

// Vtable
struct _jc_gnu_java_security_provider_Gnu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Dictionary$vmethods	java_util_Dictionary;
	_jc_java_util_Hashtable$vmethods	java_util_Hashtable;
	_jc_java_util_Properties$vmethods	java_util_Properties;
	_jc_java_security_Provider$vmethods	java_security_Provider;
	_jc_gnu_java_security_provider_Gnu$vmethods	gnu_java_security_provider_Gnu;
};

// Vtype
struct _jc_gnu_java_security_provider_Gnu$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_Gnu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_Gnu$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_Gnu$refs {
    _jc_gnu_java_security_provider_Gnu$sub_refs	gnu_java_security_provider_Gnu;
    _jc_java_security_Provider$sub_refs	java_security_Provider;
    _jc_java_util_Properties$sub_refs	java_util_Properties;
    _jc_java_util_Hashtable$sub_refs	java_util_Hashtable;
    _jc_java_util_Dictionary$sub_refs	java_util_Dictionary;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_Gnu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_Gnu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Dictionary$sub_nonrefs	java_util_Dictionary;
    _jc_java_util_Hashtable$sub_nonrefs	java_util_Hashtable;
    _jc_java_util_Properties$sub_nonrefs	java_util_Properties;
    _jc_java_security_Provider$sub_nonrefs	java_security_Provider;
    _jc_gnu_java_security_provider_Gnu$sub_nonrefs	gnu_java_security_provider_Gnu;
};

// Object instance structure
struct _jc_gnu_java_security_provider_Gnu$object {
	_jc_gnu_java_security_provider_Gnu$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_Gnu$vtype	*vtype;
	_jc_gnu_java_security_provider_Gnu$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_Gnu$vtype _jc_gnu_java_security_provider_Gnu$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_Gnu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_Gnu$class_object;

#endif	/* _JC_gnu_java_security_provider_Gnu_H_ */
